#include "config.h"
#include "cpuio.h"
#include "stddefs.h"
#include "timer.h"
#include "cli.h"
#include "stddefs.h"
#include <stdio.h>
#include <string.h>
#include "MK60D10.h"
#include "device/MK64F12/MK64F12_gpio.h"
#include "k60_tower.h"
#include "uart.h"

int ExceptionType;
unsigned long ExceptionAddr;
unsigned long LoopsPerMillisecond;

#define GPIO_PIN_MASK            0x1Fu
#define GPIO_PIN(x)              (((1)<<(x & GPIO_PIN_MASK)))

/* The PIT timer is a down-counter, so we invert the value
 * prior to returning...
 */
unsigned long
target_timer(void)
{
	return(~PIT_CVAL0);
}

/* init_pit():
 * uMon uses PIT_TIMER0 for keeping track of time.
 */
void
init_pit(void)
{
	// Enable PIT bit in system clock gating control reg...
	SIM_SCGC6 |= SIM_SCGC6_PIT_MASK;
	
	// Enable PIT timer, and allow it to run in debug mode...
	PIT_MCR = 0;
	// Set reload value to max, so that it just keeps ticking down...
	PIT_LDVAL0 = 0xffffffff;
	// Enable the timer...
	PIT_TCTRL0 = 1;
}

#if INCLUDE_BLINKLED

void
led_init(void)
{
	SIM_SCGC5 |= SIM_SCGC5_PORTD_MASK;

    //Set PTA10, PTA11, PTA28, and PTA29 (connected to LED's) for GPIO functionality
    PORTA_PCR10=(0|PORT_PCR_MUX(1));
    PORTA_PCR11=(0|PORT_PCR_MUX(1));
    PORTA_PCR28=(0|PORT_PCR_MUX(1));
    PORTA_PCR29=(0|PORT_PCR_MUX(1));

    //Change PTA10, PTA11, PTA28, PTA29 to outputs
    GPIOA_PDDR=GPIO_PDDR_PDD(GPIO_PIN(10) | GPIO_PIN(11) | GPIO_PIN(28) | GPIO_PIN(29) );
}

void
led_toggle(void)
{
    GPIOA_PTOR |= GPIO_PDOR_PDO(GPIO_PIN(10));
    GPIOA_PTOR |= GPIO_PDOR_PDO(GPIO_PIN(11));
    GPIOA_PTOR |= GPIO_PDOR_PDO(GPIO_PIN(28));
    GPIOA_PTOR |= GPIO_PDOR_PDO(GPIO_PIN(29));
}

void
blink_status_led(void)
{
	static uint8_t ledstate;
	static struct elapsed_tmr tmr;

	switch(ledstate) {
		default:
			startElapsedTimer(&tmr,INCLUDE_BLINKLED);
            ledstate = 1;
            led_toggle();
            break;
		case 1:
            if(msecElapsed(&tmr)) {
                led_toggle();
                ledstate = 2;
                startElapsedTimer(&tmr,INCLUDE_BLINKLED);
            }
            break;
		case 2:
            if(msecElapsed(&tmr)) {
                led_toggle();
                ledstate = 1;
                startElapsedTimer(&tmr,INCLUDE_BLINKLED);
            }
            break;
    }
}
#endif


void
initCPUio(void)
{
#if INCLUDE_BLINKLED
	led_init();
#endif
	init_pit();

	MPU_CESR = 0;	// Turn off the MPU for now.
}

/* uninitCPUio():
 * Target/application specific "uninitialization"
 * function used by 'call' command just prior to
 * turning over control to the application.
 */
void
uninitCPUio(void)
{
}

void
vinit()
{
}

void
intsrestore(unsigned long val)
{
}

unsigned long
intsoff(void)
{
	return(0);
}

void
cacheInitForTarget()
{
}

int
ConsoleBaudSet(int baud)
{
	return(0);
}

void
devInit(int baud)
{
	ConsoleBaudSet(baud);
}

char *
ExceptionType2String(int type)
{
	return("???");
}


/* target-specific putchar():
 * When buffer has space available, load the incoming character
 * into the UART.
 */
int
target_putchar(char c)
{
	uart_putchar(TERM_PORT, c);
	return((int)c);
}

int
target_console_empty(void)
{
    return(UART_S1_REG(TERM_PORT) & UART_S1_TDRE_MASK);
}

/* target-specific getchar():
 * Assume there is a character in the UART's input buffer and just
 * pull it out and return it.
 */
int
target_getchar(void)
{
	return(uart_getchar(TERM_PORT));
}

int
target_gotachar(void)
{
	return(uart_getchar_present(TERM_PORT));
}


void
target_reset(void)
{
#if 1
	struct elapsed_tmr tmr;

	WDOG_UNLOCK = 0xC520U;
	WDOG_UNLOCK = 0xD928U;
	WDOG_TOVALH = 0U;
	WDOG_TOVALL = 0x100U;
	WDOG_STCTRLH = 0x5f9U;

	startElapsedTimer(&tmr,2000);
	while(!msecElapsed(&tmr));
	printf("Reset failed\n");
#else
	printf("loop...\n");
	while(1);
#endif
}

void
watchdog_refresh(void)
{
	WDOG_REFRESH = 0xA602U;
	WDOG_REFRESH = 0xB480U;
}

#ifdef POSTDHCP_ACTION
void
POSTDHCP_ACTION()
{
	extern int docommand(char *,int);
	docommand("dm 0x38000",1);
}
#endif

#ifdef USR_HEADER_FUNC
#define MC_SRSL() *((unsigned char *)0x4007e001)
#define MC_SRSH() *((unsigned char *)0x4007e000)

void
reset_message(void)
{
	printf("Reset cause: ");
	if (MC_SRSL() & RCM_SRS0_WAKEUP_MASK)
		printf("WAKEUP ");
	if (MC_SRSL() & RCM_SRS0_LVD_MASK)
		printf("LVD ");
	if (MC_SRSL() & RCM_SRS0_LOC_MASK)
		printf("LOC ");
	if (MC_SRSL() & RCM_SRS0_WDOG_MASK)
		printf("WDOG ");
	if (MC_SRSL() & RCM_SRS0_PIN_MASK)
		printf("PIN ");
	if (MC_SRSL() & RCM_SRS0_POR_MASK)
		printf("POR ");

	if (MC_SRSH() & RCM_SRS1_JTAG_MASK)
		printf("JTAG ");
	if (MC_SRSH() & RCM_SRS1_LOCKUP_MASK)
		printf("LOCKUP ");
	if (MC_SRSH() & RCM_SRS1_SW_MASK)
		printf("SW ");
	printf("\n");
}
#endif
